@@ -23,7 +23,7 @@ from ..legistar_utils import (
     LEGISTAR_SESSION_DATE,
     LegistarScraper,
 )
-from ..scraper_utils import str_simplified
+from ..scraper_utils import str_simplified, parse_static_file
 from ..types import ContentURIs
 
 ###############################################################################
@@ -35,21 +35,6 @@ log = logging.getLogger(__name__)
 STATIC_FILE_KEY_PERSONS = "persons"
 STATIC_FILE_DEFAULT_PATH = Path(__file__).parent / "seattle-static.json"
 
-known_persons: Optional[Dict[str, Person]] = None
-
-# load long-term static data at file load-time
-if Path(STATIC_FILE_DEFAULT_PATH).exists():
-    with open(STATIC_FILE_DEFAULT_PATH, "rb") as json_file:
-        static_data = json.load(json_file)
-
-    known_persons = {}
-    for name, person in static_data[STATIC_FILE_KEY_PERSONS].items():
-        known_persons[name] = Person.from_dict(person)
-
-
-if known_persons:
-    log.debug(f"loaded static data for {', '.join(known_persons.keys())}")
-
 # we have discovered the city clerk accidentally entered Daniel Strauss
 # instead of the correct Dan Strauss for a few events
 PERSON_ALIASES = {"Dan Strauss": set(["Daniel Strauss"])}
@@ -83,7 +68,7 @@ class SeattleScraper(LegistarScraper):
                 r".+:$",
                 "Pursuant to Washington State",
             ],
-            known_persons=known_persons,
+            static_data=parse_static_file(STATIC_FILE_DEFAULT_PATH),
             person_aliases=PERSON_ALIASES,
         )
 
